@@ -1,6 +1,7 @@
 import argparse
 import sys
 
+from tfkit.utility import tok
 from tqdm import tqdm
 import csv
 from tfkit.utility.eval_metric import EvalMetric
@@ -63,7 +64,7 @@ def main(arg=None):
                 else:
                     predicted = ''
             elif 'onebyone' in model_type or 'seq2seq' in model_type or 'clm' in model_type:
-                processed_target = " ".join(target[0])
+                processed_target = target[0]
                 if len(result) < eval_pos:
                     print("Decode size smaller than decode num:", result_dict['label_map'])
                 predicted = result[eval_pos]
@@ -104,7 +105,7 @@ def main(arg=None):
             records = eval_metric.get_record(eval_arg.get('metric'))
             writer.writerow(['input', 'predicted', 'targets'])
             for i, p, t in zip(records['input'], records['predicted'], records['targets']):
-                writer.writerow([i, p, "[SEP]".join([onet for onet in t if len(onet) > 0])])
+                writer.writerow([i, p, tok.tok_sep(model.tokenizer).join([onet for onet in t if len(onet) > 0])])
         print("write result at:", outfile_name)
 
         with open(outfile_name + "_each_data_score.csv", "w", encoding='utf8') as edsf:
